@@ -26,7 +26,7 @@
 #include <akonadi/item.h>
 #include <kcalcore/memorycalendar.h>
 #include <kcalcore/incidence.h>
-#include <KDateTime>
+#include <KDE/KDateTime>
 
 namespace Akonadi {
 
@@ -55,7 +55,7 @@ public:
   /**
     * Constructs a CalendarBase object.
     */
-  explicit CalendarBase();
+  explicit CalendarBase( QObject *parent = 0 );
 
   /**
     * Destroys the calendar.
@@ -65,14 +65,27 @@ public:
   /**
     * Returns the Item containing the incidence with uid @p uid or an invalid Item
     * if the incidence isn't found.
+    * @see Use item(Incidence::Ptr) instead where possible. This function doesn't take exceptions (recurrenceId) into account (and thus always returns the main event).
     */
   Akonadi::Item item( const QString &uid ) const;
 
+  /**
+    * Returns the Item containing the incidence with uid @p uid or an invalid Item
+    * if the incidence isn't found.
+    */
+  Akonadi::Item item( const KCalCore::Incidence::Ptr &inc ) const;
+
   /**
     * Returns the Item with @p id or an invalid Item if not found.
     */
   Akonadi::Item item( Akonadi::Item::Id ) const;
 
+  /**
+   *  Returns the list of items contained in this calendar.
+   *  @see incidences()
+   */
+  Akonadi::Item::List items() const;
+
   /**
     * Returns the item list that corresponds to the @p incidenceList.
     */
@@ -81,24 +94,28 @@ public:
   /**
     * Returns the child incidences of the parent identified by @p parentUid.
     * Only the direct childs are returned
+    * @param parentUid identifier of the parent incidence
     */ //TODO: unit-test
   KCalCore::Incidence::List childIncidences( const QString &parentUid ) const;
 
   /**
     * Returns the child incidences of the parent identified by @p parentId.
     * Only the direct childs are returned
+    * @param parentId identifier of the parent item
     */
   KCalCore::Incidence::List childIncidences( const Akonadi::Item::Id &parentId ) const;
 
   /**
     * Returns the child items of the parent identified by @p parentUid.
     * Only the direct childs are returned
+    * @param parentUid identifier of the parent incidence
     */
   Akonadi::Item::List childItems( const QString &parentUid ) const;
 
   /**
     * Returns the child items of the parent identified by @p parentId.
     * Only the direct childs are returned
+    * @param parentId identifier of the parent item
     */
   Akonadi::Item::List childItems( const Akonadi::Item::Id &parentId ) const;
 
@@ -125,12 +142,14 @@ public:
   /**
     * Adds an Event to the calendar.
     * It's added to akonadi in the background @see createFinished().
+    * @param event the event to be added
     */
   /**reimp*/ bool addEvent( const KCalCore::Event::Ptr &event );
 
   /**
     * Deletes an Event from the calendar.
     * It's removed from akonadi in the background @see deleteFinished().
+    * @param event the event to be deleted
     */
   /**reimp*/ bool deleteEvent( const KCalCore::Event::Ptr &event );
 
@@ -143,12 +162,14 @@ public:
   /**
     * Adds a Todo to the calendar.
     * It's added to akonadi in the background @see createFinished().
+    * @param todo the todo to add
     */
   /**reimp*/ bool addTodo( const KCalCore::Todo::Ptr &todo );
 
   /**
     * Deletes a Todo from the calendar.
     * It's removed from akonadi in the background @see deleteFinished().
+    * @param todo the todo to delete
     */
   /**reimp*/ bool deleteTodo( const KCalCore::Todo::Ptr &todo );
 
@@ -161,12 +182,14 @@ public:
   /**
     * Adds a Journal to the calendar.
     * It's added to akonadi in the background @see createFinished().
+    * @param journal the journal to add
     */
   /**reimp*/ bool addJournal( const KCalCore::Journal::Ptr &journal );
 
   /**
     * Deletes a Journal from the calendar.
     * It's removed from akonadi in the background @see deleteFinished().
+    * @param journal the journal to delete
     */
   /**reimp*/ bool deleteJournal( const KCalCore::Journal::Ptr &journal );
 
@@ -179,12 +202,14 @@ public:
   /**
     * Adds an incidence to the calendar.
     * It's added to akonadi in the background @see createFinished().
+    * @param incidence the incidence to add
     */
   /**reimp*/ bool addIncidence( const KCalCore::Incidence::Ptr &incidence );
 
   /**
     * Deletes an incidence from the calendar.
     * It's removed from akonadi in the background @see deleteFinished().
+    * @param incidence the incidence to delete
     */
   /**reimp*/ bool deleteIncidence( const KCalCore::Incidence::Ptr & );
 
@@ -211,9 +236,9 @@ public:
   /**
     * Modifies an incidence.
     * The incidence with the same uid as @p newIncidence will be updated with the contents of
-    * @p newIncidence.
+    * @param newIncidence the incidence to modify
     */
-  bool modifyIncidence( const KCalCore::IncidenceBase::Ptr &newIncidence );
+  bool modifyIncidence( const KCalCore::Incidence::Ptr &newIncidence );
 
 Q_SIGNALS:
   /**
@@ -243,7 +268,7 @@ Q_SIGNALS:
 protected:
   Q_DECLARE_PRIVATE( CalendarBase )
   QScopedPointer<CalendarBasePrivate> d_ptr;
-  CalendarBase( CalendarBasePrivate *const d );
+  CalendarBase( CalendarBasePrivate *const d, QObject *parent );
 };
 }
 
