@@ -502,7 +502,7 @@ bool IncidenceChanger::Private::handleInvitationsBeforeChange( const Change::Ptr
 
 bool IncidenceChanger::Private::handleInvitationsAfterChange( const Change::Ptr &change )
 {
-  if ( mGroupwareCommunication ) {
+  if ( change->useGroupwareCommunication ) {
     ITIPHandlerHelper handler( change->parentWidget ); // TODO make async
     switch( change->type ) {
       case IncidenceChanger::ChangeTypeCreate:
@@ -876,6 +876,9 @@ int IncidenceChanger::modifyIncidence( const Item &changedItem,
     return changeId;
   }
 
+  //TODO also update revision here instead of in the editor
+  changedItem.payload<Incidence::Ptr>()->setLastModified( KDateTime::currentUtcDateTime() );
+
   const uint atomicOperationId = d->mBatchOperationInProgress ? d->mLatestAtomicOperationId : 0;
   const int changeId = ++d->mLatestChangeId;
   ModificationChange *modificationChange = new ModificationChange( this, changeId,
