@@ -40,11 +40,10 @@
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kstandarddirs.h>
 #include <ktabwidget.h>
 #include <ktextedit.h>
-#include <kurlrequester.h>
 
 #include <Nepomuk2/ResourceManager>
 
