@@ -26,7 +26,7 @@
 #include <kdatepicker.h>
 #include <kglobal.h>
 #include <kicon.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <QContextMenuEvent>
 #include <QHBoxLayout>
@@ -37,7 +37,7 @@ DateView::DateView( QWidget *parent )
   : QLabel( parent )
 {
   setTextInteractionFlags( Qt::TextSelectableByMouse );
-  setFrameShape( QFrame::Panel );
+  setFrameShape( QFrame::StyledPanel );
   setFrameShadow( QFrame::Sunken );
 }
 
