@@ -41,7 +41,7 @@ namespace Akonadi {
 class AKONADI_TESTS_EXPORT SessionPrivate
 {
   public:
-    SessionPrivate( Session *parent );
+    explicit SessionPrivate( Session *parent );
 
     virtual ~SessionPrivate()
     {
@@ -65,6 +65,7 @@ class AKONADI_TESTS_EXPORT SessionPrivate
 
     /**
       @internal For testing purposes only. See FakeSesson.
+      @param job the job to end
     */
     void endJob( Job* job );
 
@@ -82,6 +83,7 @@ class AKONADI_TESTS_EXPORT SessionPrivate
      * You only need to call this method if you want that the
      * default session has a special custom id, otherwise a random unique
      * id is used automatically.
+     * @param sessionId the id of new default session
      */
     static void createDefaultSession( const QByteArray &sessionId );
 
@@ -111,7 +113,7 @@ class AKONADI_TESTS_EXPORT SessionPrivate
      */
     void itemRevisionChanged( Akonadi::Item::Id itemId, int oldRevision, int newRevision );
 
-    static int minimumProtocolVersion() { return 29; }
+    static int minimumProtocolVersion() { return 32; }
 
     /**
      * Default location for akonadiconnectionrc
