@@ -31,9 +31,11 @@
 #endif
 #include <kglobal.h>
 #include <klocale.h>
+#include <klocalizedstring.h>
 #include <kdebug.h>
 
 #include <QBitArray>
+#include <QDateTime>
 
 
 #ifndef KALARMCAL_USE_KRESOURCES
