@@ -36,6 +36,8 @@
 
 #include <KDebug>
 
+#include <QTime>
+
 using namespace KCalCore;
 
 /**
@@ -47,10 +49,7 @@ class KCalCore::Todo::Private
 {
   public:
     Private()
-      : mPercentComplete( 0 ),
-        mHasDueDate( false ),
-        mHasStartDate( false ),
-        mHasCompletedDate( false )
+      : mPercentComplete( 0 )
     {}
     Private( const KCalCore::Todo::Private &other )
     { init( other ); }
@@ -62,9 +61,6 @@ class KCalCore::Todo::Private
     KDateTime mDtRecurrence; // next occurrence (for recurring to-dos)
     KDateTime mCompleted;    // to-do completion date (if it has been completed)
     int mPercentComplete;    // to-do percent complete [0,100]
-    bool mHasDueDate;        // true if the to-do has a due date
-    bool mHasStartDate;      // true if the to-do has a starting date
-    bool mHasCompletedDate;  // true if the to-do has a completion date
 
     /**
       Returns true if the todo got a new date, else false will be returned.
@@ -78,9 +74,6 @@ void KCalCore::Todo::Private::init( const KCalCore::Todo::Private &other )
   mDtRecurrence = other.mDtRecurrence;
   mCompleted = other.mCompleted;
   mPercentComplete = other.mPercentComplete;
-  mHasDueDate = other.mHasDueDate;
-  mHasStartDate = other.mHasStartDate;
-  mHasCompletedDate = other.mHasCompletedDate;
 }
 
 //@endcond
@@ -156,18 +149,15 @@ void Todo::setDtDue( const KDateTime &dtDue, bool first )
       alarm->setTime(alarm->time().addSecs(diffsecs));
     }
   }*/
-  d->mHasDueDate = dtDue.isValid();
 
   if ( recurs() && !first ) {
     d->mDtRecurrence = dtDue;
   } else {
     d->mDtDue = dtDue;
-    // TODO: This doesn't seem right...
-    recurrence()->setStartDateTime( dtDue );
-    recurrence()->setAllDay( allDay() );
   }
 
-  if ( recurs() && dtDue < recurrence()->startDateTime() ) {
+  if ( recurs() && dtDue.isValid() && ( !dtStart().isValid() || dtDue < recurrence()->startDateTime() ) ) {
+    kDebug() << "To-do recurrences are now calculated against DTSTART. Fixing legacy to-do.";
     setDtStart( dtDue );
   }
 
@@ -192,7 +182,7 @@ KDateTime Todo::dtDue( bool first ) const
 
 bool Todo::hasDueDate() const
 {
-  return d->mHasDueDate;
+  return d->mDtDue.isValid();
 }
 
 void Todo::setHasDueDate( bool f )
@@ -201,14 +191,17 @@ void Todo::setHasDueDate( bool f )
     return;
   }
   update();
-  d->mHasDueDate = f;
+  if ( !f ) {
+    d->mDtDue = KDateTime();
+    d->mDtRecurrence = KDateTime();
+  }
   setFieldDirty( FieldDtDue );
   updated();
 }
 
 bool Todo::hasStartDate() const
 {
-  return d->mHasStartDate;
+  return IncidenceBase::dtStart().isValid() || d->mDtRecurrence.isValid();
 }
 
 void Todo::setHasStartDate( bool f )
@@ -226,7 +219,9 @@ void Todo::setHasStartDate( bool f )
     QString s( "NoStartDate" );
     removeComment( s );
   }
-  d->mHasStartDate = f;
+  if ( !f ) {
+    setDtStart( KDateTime() );
+  }
   setFieldDirty( FieldDtStart );
   updated();
 }
@@ -241,7 +236,7 @@ KDateTime Todo::dtStart( bool first ) const
   if ( !hasStartDate() ) {
     return KDateTime();
   }
-  if ( recurs() && !first ) {
+  if ( recurs() && !first && d->mDtRecurrence.isValid() ) {
     KDateTime dt = d->mDtRecurrence.addDays( dtDue( true ).daysTo( IncidenceBase::dtStart() ) );
     dt.setTime( IncidenceBase::dtStart().time() );
     return dt;
@@ -252,15 +247,7 @@ KDateTime Todo::dtStart( bool first ) const
 
 void Todo::setDtStart( const KDateTime &dtStart )
 {
-  // TODO: This doesn't seem right (rfc 2445/6 says, recurrence is calculated from the dtstart...)
-
-  d->mHasStartDate = dtStart.isValid();
-
-  if ( recurs() ) {
-    recurrence()->setStartDateTime( d->mDtDue );
-    recurrence()->setAllDay( allDay() );
-  }
-  IncidenceBase::setDtStart( dtStart );
+  Incidence::setDtStart( dtStart );
 }
 
 bool Todo::isCompleted() const
@@ -275,7 +262,6 @@ void Todo::setCompleted( bool completed )
     d->mPercentComplete = 100;
   } else {
     d->mPercentComplete = 0;
-    d->mHasCompletedDate = false;
     d->mCompleted = KDateTime();
   }
   setFieldDirty( FieldCompleted );
@@ -295,7 +281,6 @@ void Todo::setCompleted( const KDateTime &completed )
 {
   update();
   if ( !d->recurTodo( this ) ) {
-    d->mHasCompletedDate = true;
     d->mPercentComplete = 100;
     d->mCompleted = completed.toUtc();
     setFieldDirty( FieldCompleted );
@@ -305,7 +290,7 @@ void Todo::setCompleted( const KDateTime &completed )
 
 bool Todo::hasCompletedDate() const
 {
-  return d->mHasCompletedDate;
+  return d->mCompleted.isValid();
 }
 
 int Todo::percentComplete() const
@@ -324,7 +309,7 @@ void Todo::setPercentComplete( int percent )
   update();
   d->mPercentComplete = percent;
   if ( percent != 100 ) {
-    d->mHasCompletedDate = false;
+    d->mCompleted = KDateTime();
   }
   setFieldDirty( FieldPercentComplete );
   updated();
@@ -340,7 +325,7 @@ bool Todo::isInProgress( bool first ) const
     return true;
   }
 
-  if ( d->mHasStartDate && d->mHasDueDate ) {
+  if ( hasStartDate() && hasDueDate() ) {
     if ( allDay() ) {
       QDate currDate = QDate::currentDate();
       if ( dtStart( first ).date() <= currDate && currDate < dtDue( first ).date() ) {
@@ -359,7 +344,7 @@ bool Todo::isInProgress( bool first ) const
 
 bool Todo::isOpenEnded() const
 {
-  if ( !d->mHasDueDate && !isCompleted() ) {
+  if ( !hasDueDate() && !isCompleted() ) {
     return true;
   }
   return false;
@@ -372,7 +357,7 @@ bool Todo::isNotStarted( bool first ) const
     return false;
   }
 
-  if ( !d->mHasStartDate ) {
+  if ( !hasStartDate() ) {
     return false;
   }
 
@@ -398,7 +383,7 @@ void Todo::shiftTimes( const KDateTime::Spec &oldSpec,
     d->mDtRecurrence = d->mDtRecurrence.toTimeSpec( oldSpec );
     d->mDtRecurrence.setTimeSpec( newSpec );
   }
-  if ( d->mHasCompletedDate ) {
+  if ( hasCompletedDate() ) {
     d->mCompleted = d->mCompleted.toTimeSpec( oldSpec );
     d->mCompleted.setTimeSpec( newSpec );
   }
@@ -439,7 +424,7 @@ bool Todo::isOverdue() const
 void Todo::setAllDay( bool allday )
 {
   if ( allday != allDay() && !mReadOnly ) {
-    if ( hasDueDate() && dtDue().isValid() ) {
+    if ( hasDueDate() ) {
       setFieldDirty( FieldDtDue );
     }
     Incidence::setAllDay( allday );
@@ -479,7 +464,7 @@ bool Todo::Private::recurTodo( Todo *todo )
         nextOccurrenceDateTime = r->getNextDateTime( nextOccurrenceDateTime );
       }
 
-      todo->setDtDue( nextOccurrenceDateTime );
+      todo->setDtRecurrence( nextOccurrenceDateTime );
       todo->setCompleted( false );
       todo->setRevision( todo->revision() + 1 );
 
@@ -533,10 +518,13 @@ KDateTime Todo::dateTime( DateTimeRole role ) const
       }
     }
   case RoleRecurrenceStart:
-    return dtDue();
-    break;
+    if ( dtStart().isValid() ) {
+      return dtStart();
+    }
+    return dtDue(); //For the sake of backwards compatibility
+                    //where we calculated recurrences based on dtDue
   case RoleEnd:
-    // todos don't have dtEnd
+    return dtDue();
   default:
     return KDateTime();
   }
@@ -548,6 +536,9 @@ void Todo::setDateTime( const KDateTime &dateTime, DateTimeRole role )
     case RoleDnD:
       setDtDue( dateTime );
       break;
+    case RoleEnd:
+      setDtDue( dateTime, true );
+      break;
     default:
       kDebug() << "Unhandled role" << role;
   }
